@@ -94,7 +94,10 @@ class RowParser(object):
 
   def get_latency(self):
     return self._get_val('latency')
-
+  
+  def get_float_latency(self):
+    return float(self.get_latency())
+  
   def is_valid_line(self,https=[]):
     try:
       code=int(self.get_code())
@@ -320,4 +323,4 @@ class CachePickle(Cache,dict):
       res.append("%s %s"%(k,pickled))
     return res
     
-    
\ No newline at end of file
+    
